@@ -21,39 +21,41 @@
   without including the source code for Qt in the source distribution.
 */
 
-#include <qbuttongroup.h>
-#include <qcheckbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include "kcmweather.h"
+#include "dockwidget.h"
+#include "serviceinterface.h"
+
+#include <Qt3Support/Q3ButtonGroup>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QVBoxLayout>
+#include <QtGui/QFocusEvent>
 
 #include <kaboutdata.h>
-#include <kapplication.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kurlrequester.h>
 #include <kcombobox.h>
+#include <ktoolinvocation.h>
 #include <kcolorbutton.h>
-
-#include "dockwidget.h"
-#include "prefdialogdata.h"
-
-#include "kcmweather.h"
-#include "weatherservice_stub.h"
+#include <kcomponentdata.h>
 
 extern "C"
 {
   KDE_EXPORT KCModule *create_weather( QWidget *parent, const char * )
   {
-    return new KCMWeather( parent, "kweather" );
+    return new KCMWeather( parent);
   }
 }
 
-KCMWeather::KCMWeather( QWidget *parent, const char *name )
-  : KCModule( parent, name )
+KCMWeather::KCMWeather( QWidget *parent)
+  : KCModule(KComponentData("kweather"))
 {
-  mWeatherService = new WeatherService_stub( "KWeatherService",
-      "WeatherService" );
+  Q_UNUSED(parent)
+
+  mWeatherService = new OrgKdeKweatherServiceInterface( "org.kde.KWeatherService", "/Service", QDBusConnection::sessionBus() );
   QVBoxLayout *layout = new QVBoxLayout( this );
   mWidget = new prefsDialogData( this );
 
@@ -73,18 +75,17 @@ KCMWeather::KCMWeather( QWidget *parent, const char *name )
                                  SLOT( textColorChanged(const QColor &) ) );
 
   KAboutData *about = new KAboutData(
-      I18N_NOOP( "kcmweather" ),
-      I18N_NOOP( "KWeather Configure Dialog" ),
-      0, 0, KAboutData::License_GPL,
-      I18N_NOOP( "(c), 2003 Tobias Koenig" ) );
+      I18N_NOOP( "kcmweather" ), 0,
+      ki18n( "KWeather Configure Dialog" ),
+      0, KLocalizedString(), KAboutData::License_GPL,
+      ki18n( "(c), 2003 Tobias Koenig" ) );
 
-  about->addAuthor( "Tobias Koenig", 0, "tokoe@kde.org" );
+  about->addAuthor( ki18n("Tobias Koenig"), KLocalizedString(), "tokoe@kde.org" );
   setAboutData(about);
 }
 
 KCMWeather::~KCMWeather()
 {
-  delete mWeatherService;
 }
 void KCMWeather::showEvent( QShowEvent * )
 {
@@ -124,7 +125,7 @@ void KCMWeather::fillStationList()
     for (int i = 0; i < mWidget->m_reportLocation->count(); i++)
       if (  mWidget->m_reportLocation->text(i) == current )
       {
-        mWidget->m_reportLocation->setCurrentItem(i);
+        mWidget->m_reportLocation->setCurrentIndex(i);
         break;
       }
   }
@@ -149,7 +150,7 @@ void KCMWeather::enableLogWidgets( bool value )
 
 void KCMWeather::reportLocationChanged()
 {
-  kdDebug() << "New station: " << mWidget->m_reportLocation->currentText()
+  kDebug() << "New station: " << mWidget->m_reportLocation->currentText()
       << " Code: " << mWeatherService->stationCode( mWidget->m_reportLocation->currentText() ) << endl;
   emit changed( true );
 }
@@ -161,48 +162,46 @@ void KCMWeather::textColorChanged(const QColor &)
 
 void KCMWeather::load()
 {
-  kdDebug() << "Load" << endl;
+  kDebug() << "Load";
   KConfig config( "weather_panelappletrc" );
-
-  config.setGroup( "General Options" );
-  bool enabled = config.readBoolEntry( "logging", false );
+  KConfigGroup group = config.group("General Options" );
+  bool enabled = group.readEntry( "logging", QVariant(false )).toBool();
   mWidget->m_enableLog->setChecked( enabled );
   enableLogWidgets( enabled );
 
-  static QColor black(Qt::black);
-  QColor textColor = config.readColorEntry("textColor", &black);
+  QColor textColor = group.readEntry("textColor", QColor(Qt::black));
   mWidget->m_textColor->setColor(textColor);
 
-  QString loc =  config.readEntry( "report_location" );
+  QString loc = group.readEntry( "report_location" );
 
-  mWidget->m_logFile->setURL( config.readPathEntry( "log_file_name" ) );
+  mWidget->m_logFile->setUrl( group.readPathEntry( "log_file_name", QString() ) );
 
   if ( ! loc.isEmpty() )
     mWidget->m_reportLocation->setCurrentText( mWeatherService->stationName( loc ) );
 
-  mWidget->m_viewMode->setButton( config.readNumEntry( "smallview_mode", dockwidget::ShowAll ) );
-  changeViewMode( config.readNumEntry( "smallview_mode", dockwidget::ShowAll ) );
+  mWidget->m_viewMode->setButton( group.readEntry( "smallview_mode", int(dockwidget::ShowAll) ) );
+  changeViewMode( group.readEntry( "smallview_mode", int(dockwidget::ShowAll) ) );
   emit changed( false );
 }
 
 void KCMWeather::save()
 {
-  kdDebug() << "Save" << endl;
+  kDebug() << "Save";
   KConfig config( "weather_panelappletrc" );
 
-  config.setGroup( "General Options" );
-  config.writeEntry( "logging", mWidget->m_enableLog->isChecked() );
-  config.writeEntry( "log_file_name", mWidget->m_logFile->url() );
-  config.writeEntry( "textColor", mWidget->m_textColor->color() );
+  KConfigGroup group = config.group("General Options" );
+  group.writeEntry( "logging", mWidget->m_enableLog->isChecked() );
+  group.writeEntry( "log_file_name", mWidget->m_logFile->url().path() );
+  group.writeEntry( "textColor", mWidget->m_textColor->color() );
 
   // Station idx to local idx; if nothing selected yet, keep it empty
   QString loc;
   if ( ! mWidget->m_reportLocation->currentText().isEmpty() )
     loc = mWeatherService->stationCode( mWidget->m_reportLocation->currentText() );
-  config.writeEntry( "report_location", loc);
+  group.writeEntry( "report_location", loc);
 
-  config.writeEntry( "smallview_mode", mViewMode );
-  config.sync();
+  group.writeEntry( "smallview_mode", mViewMode );
+  group.sync();
 
   emit changed( false );
 }
@@ -212,7 +211,7 @@ void KCMWeather::defaults()
   mWidget->m_enableLog->setChecked( false );
   enableLogWidgets( false );
 
-  mWidget->m_logFile->setURL( "" );
+  mWidget->m_logFile->setUrl( KUrl("") );
   mWidget->m_reportLocation->setCurrentText( "" );
   changeViewMode( dockwidget::ShowAll );
 
