@@ -80,4 +80,4 @@ private: // Private methods
 	QColor mTextColor;
 };
 
-#endif
+#endif // KWEATHER_H
