@@ -16,11 +16,11 @@
  *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  *  Boston, MA 02110-1301, USA.
  *
- *  $Id: sidebarwidget.h 631359 2007-02-07 20:22:23Z aseigo $
+ *  $Id: sidebarwidget.h 889437 2008-11-26 20:41:28Z schwarzer $
  */
 
-#ifndef __SIDEBARWIDGET_H__
-#define __SIDEBARWIDGET_H__
+#ifndef SIDEBARWIDGET_H
+#define SIDEBARWIDGET_H
 
 
 #include <sidebarwidgetbase.h>
@@ -38,6 +38,6 @@ public:
 
 };
 
-#endif
+#endif // SIDEBARWIDGET_H
 
 
